@@ -3,7 +3,7 @@ ecospat.migclim<-function()
 message("load the MigClim package")
   packageStartupMessage("initializing ...")
   Sys.sleep(1)
-library(MigClim)
+requireNamespace("MigClim")
 
 Sys.sleep(1)
 packageStartupMessage("... done")
