@@ -53,38 +53,38 @@
 
 ##################################################################################################
 
-ecospat.grid.clim.dyn<-function(glob,glob1,sp,R,th.sp=0,th.env=0){
-
-l<-list()
-
-if (ncol(glob)>2) stop("cannot calculate overlap with more than two axes")
-
-if(ncol(glob)==1){ 											#if scores in one dimension (e.g. LDA,SDM predictions,...)
-	xmax<-max(glob[,1])
-	xmin<-min(glob[,1])
-	sp.dens<-density(sp[,1],kernel="gaussian",from=xmin,to=xmax,n=R,cut=0) 		# calculate the density of occurrences in a vector of R pixels along the score gradient
-														# using a gaussian kernel density function, with R bins.
-	glob1.dens<-density(glob1[,1],kernel="gaussian",from=xmin,to=xmax,n=R,cut=0)	# calculate the density of environments in glob1
-	x<-sp.dens$x 											# breaks on score gradient
-	z<-sp.dens$y*nrow(sp)/sum(sp.dens$y) 							# rescale density to the number of occurrences in sp
-							 							# number of occurrence/pixel
-	Z<-glob1.dens$y*nrow(glob)/sum(glob1.dens$y) 						# rescale density to the number of sites in glob1
-	z[z<max(z)/nrow(sp)]<-0 										# remove infinitesimally small number generated by kernel density function
-	Z[Z<max(Z)/nrow(glob1)]<-0 										# remove infinitesimally small number generated by kernel density function
-
-	z.uncor<-z/max(z)											# rescale between [0:1] for comparison with other species
-	z<-z/Z												# correct for environment prevalence
-	z[is.na(z)]<-0 											# remove n/0 situations
-	z[z=="Inf"]<-0 											# remove 0/0 situations
-	z.cor<-z/max(z)											# rescale between [0:1] for comparison with other species
-	w<-z
-	w[w>0]<-1
-	l$x<-x;l$z.uncor<-z.uncor;l$z.cor<-z.cor;l$Z<-Z;l$glob<-glob;l$glob1<-glob1;l$sp<-sp;l$w<-w
-}
-
-if(ncol(glob)==2){ #if scores in two dimensions (e.g. PCA)
-
-xmin<-min(glob[,1]);xmax<-max(glob[,1]);ymin<-min(glob[,2]);ymax<-max(glob[,2])			# data preparation
+ecospat.grid.clim.dyn<-function(glob,glob1,sp,R,th.sp=NULL,th.env=0){
+  
+  l<-list()
+  
+  if (ncol(glob)>2) stop("cannot calculate overlap with more than two axes")
+  
+  if(ncol(glob)==1){   										#if scores in one dimension (e.g. LDA,SDM predictions,...)
+    xmax<-max(glob[,1])
+    xmin<-min(glob[,1])
+    sp.dens<-density(sp[,1],kernel="gaussian",from=xmin,to=xmax,n=R,cut=0) 		# calculate the density of occurrences in a vector of R pixels along the score gradient
+    # using a gaussian kernel density function, with R bins.
+    glob1.dens<-density(glob1[,1],kernel="gaussian",from=xmin,to=xmax,n=R,cut=0)	# calculate the density of environments in glob1
+    x<-sp.dens$x 											# breaks on score gradient
+    z<-sp.dens$y*nrow(sp)/sum(sp.dens$y) 							# rescale density to the number of occurrences in sp
+    # number of occurrence/pixel
+    Z<-glob1.dens$y*nrow(glob)/sum(glob1.dens$y) 						# rescale density to the number of sites in glob1
+    z[z<max(z)/nrow(sp)]<-0 										# remove infinitesimally small number generated by kernel density function
+    Z[Z<max(Z)/nrow(glob1)]<-0 										# remove infinitesimally small number generated by kernel density function
+    
+    z.uncor<-z/max(z)											# rescale between [0:1] for comparison with other species
+    z<-z/Z												# correct for environment prevalence
+    z[is.na(z)]<-0 											# remove n/0 situations
+    z[z=="Inf"]<-0 											# remove 0/0 situations
+    z.cor<-z/max(z)											# rescale between [0:1] for comparison with other species
+    w<-z
+    w[w>0]<-1
+    l$x<-x;l$z.uncor<-z.uncor;l$z.cor<-z.cor;l$Z<-Z;l$glob<-glob;l$glob1<-glob1;l$sp<-sp;l$w<-w
+  }
+  
+  if(ncol(glob)==2){ #if scores in two dimensions (e.g. PCA)
+    
+    xmin<-min(glob[,1]);xmax<-max(glob[,1]);ymin<-min(glob[,2]);ymax<-max(glob[,2])			# data preparation
     glob1r<-data.frame(cbind((glob1[,1]-xmin)/abs(xmax-xmin),(glob1[,2]-ymin)/abs(ymax-ymin)))	# data preparation
     spr<-data.frame(cbind((sp[,1]-xmin)/abs(xmax-xmin),(sp[,2]-ymin)/abs(ymax-ymin))) 			# data preparation
     mask<-ascgen(SpatialPoints(cbind((1:R)/R,(1:R)/R)),nrcol=R-2,count=F)								# data preparation
@@ -105,9 +105,11 @@ xmin<-min(glob[,1]);xmax<-max(glob[,1]);ymin<-min(glob[,2]);ymax<-max(glob[,2])
     Z<-matrix(glob1.dens*nrow(glob1)/sum(glob1.dens),nrow=R,ncol=R,byrow=F) 	#rescale density to the number of sites in glob1
     spr<-pts2img(sp,cbind(x,y))
     glob1r<-pts2img(glob1,cbind(x,y))
-    z.th<-quantile(as.vector(z[which(spr==1)]),th.sp)
-    Z.th<-quantile(as.vector(Z[which(glob1r[]==1)]),th.env)  
-    z[z<z.th]<-0 					#z[z<max(z)/(nrow(sp)/6)]<-0 or z[z<(nrow(sp)^(1/6)*0.005)]<-0 				# remove infinitesimally small number generated by kernel density function
+    if(!is.null(th.sp)){
+      z.th<-quantile(as.vector(z[which(spr==1)]),th.sp)
+      z[z<z.th]<-0   				#z[z<max(z)/(nrow(sp)/6)]<-0 or z[z<(nrow(sp)^(1/6)*0.005)]<-0 				# remove infinitesimally small number generated by kernel density function
+     }
+    Z.th<-quantile(as.vector(Z[which(glob1r[]==1)]),th.env)
     Z[Z<Z.th]<-0     # [Z<(nrow(glob1)^(1/6)*0.005)]
     z.uncor<-z/max(z)											# rescale between [0:1] for comparison with other species  
     w<-z.uncor 											# remove infinitesimally small number generated by kernel density function
@@ -117,8 +119,8 @@ xmin<-min(glob[,1]);xmax<-max(glob[,1]);ymin<-min(glob[,2]);ymax<-max(glob[,2])
     z[z=="Inf"]<-0            	# remove n/0 situations
     z.cor<-z/max(z)											# rescale between [0:1] for comparison with other species
     l$x<-x;l$y<-y;l$z.uncor<-z.uncor;l$z.cor<-z.cor;l$Z<-Z;l$glob<-glob;l$glob1<-glob1;l$sp<-sp;l$w<-w
-    }
-return(l)
+  }
+  return(l)
 }
 
 ##################################################################################################
